﻿namespace WpfAppStackedColumnSerie
{
    using System;
    using System.Linq;
    using System.Collections.ObjectModel;
    using System.Windows;
    using System.Windows.Data;

    using Infragistics;
    using Infragistics.Controls.Charts;
    using System.Windows.Controls;
    using System.Reflection;

    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void stack_SeriesCreated(object sender, StackedSeriesCreatedEventArgs e)
        {
            StackedFragmentSeries series = sender as StackedFragmentSeries;
            e.Title = series.ValueMemberPath.Replace("_Emission", string.Empty);
        }
    }

    /// <summary>
    /// The test emissions collection.
    /// </summary>
    public class TestEmissionsCollection
        : ObservableCollection<InstalationEmissionDateInformation>
    {
        public TestEmissionsCollection()
        {
            Add(new InstalationEmissionDateInformation("A", 5, "1/1/2012", 1));
            Add(new InstalationEmissionDateInformation("B", 2, "1/1/2012", 1));
            Add(new InstalationEmissionDateInformation("C", 7, "1/1/2012", 1));
            Add(new InstalationEmissionDateInformation("A", 6, "1/2/2012", 1));
            Add(new InstalationEmissionDateInformation("B", 3, "1/2/2012", 1));
            Add(new InstalationEmissionDateInformation("C", 8, "1/2/2012", 1));
            Add(new InstalationEmissionDateInformation("A", 6, "1/3/2012", 1));
            Add(new InstalationEmissionDateInformation("B", 3, "1/3/2012", 1));
            Add(new InstalationEmissionDateInformation("C", 6, "1/3/2012", 1));
            Add(new InstalationEmissionDateInformation("A", 4, "1/4/2012", 1));
            Add(new InstalationEmissionDateInformation("B", 3, "1/4/2012", 1));
            Add(new InstalationEmissionDateInformation("C", 7, "1/4/2012", 1));
        }
    }

    /// <summary>
    /// The instalation emission date information.
    /// </summary>
    public class InstalationEmissionDateInformation
    {
        public string Installation { get; set; }
        public Decimal Emission { get; set; }
        public string Date { get; set; }
        public Decimal Assignation { get; set; }

        public InstalationEmissionDateInformation(
            string installation,
            Decimal emission,
            string date,
            Decimal assignation)
        {
            Installation = installation;
            Emission = emission;
            Date = date;
            Assignation = assignation;
        }
    }

    public class KeyConverter
       : IValueConverter
    {
        /// <summary>
        /// The convert.
        /// </summary>
        /// <param name="value">
        /// The value.
        /// </param>
        /// <param name="targetType">
        /// The target type.
        /// </param>
        /// <param name="parameter">
        /// The parameter.
        /// </param>
        /// <param name="culture">
        /// The culture.
        /// </param>
        /// <returns>
        /// The <see cref="object"/>.
        /// </returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value is string && parameter is string)
            {
                var key = (string)value;
                var param = (string)parameter;

                key = key.Replace(param, string.Empty);

                return key;
            }

            return string.Empty;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ValueFromMemberPath : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (values == null || values[0] == DependencyProperty.UnsetValue || values[1] == DependencyProperty.UnsetValue)
                return null;

            string valueMemberPath = (string)values[0];

            PropertyInfo pInfo = values[1].GetType().GetProperty(valueMemberPath);
            decimal v = (decimal)pInfo.GetValue(values[1], null);
            return v.ToString();
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
